@@ -4,11 +4,10 @@
 package main
 
 import (
-	"cmp"
 	"fmt"
 	"log"
 	"os"
-	"slices"
+	"sort"
 	"strings"
 )
 
@@ -63,7 +62,7 @@ func newBinfmtChecker(tags tagFilter) binfmtChecker {
 	}
 }
 
-func (cc binfmtChecker) check(pkg2files map[string][]string) []binfmtErr {
+func (cc binfmtChecker) check(pkg2files map[string][]string) []error {
 	if !cc.emitInterpreterTags && !cc.emitDetectorTags {
 		return nil
 	}
@@ -75,7 +74,7 @@ func (cc binfmtChecker) check(pkg2files map[string][]string) []binfmtErr {
 	}
 
 	formats := cc.binfmtFormats()
-	var tags []binfmtErr
+	var tags []error
 	for _, fmt := range formats {
 		if cc.emitInterpreterTags {
 			if fmt.name == "" || fmt.interpreter == "" || fmt.pkg == "" || !pkgs[fmt.pkg] {
@@ -208,9 +207,7 @@ func (cc binfmtChecker) binfmtFormats() []format {
 	for _, f := range formats {
 		fmts = append(fmts, f)
 	}
-	slices.SortFunc(fmts, func(a, b format) int {
-		return cmp.Compare(a.name, b.name)
-	})
+	sort.Slice(fmts, func(a, b int) bool { return fmts[a].name < fmts[b].name })
 
 	return fmts
 }
